from taibun.taibun import Converter
from utils import checker, bilabial_c, alveolar_c, alveolo_palatal_c, velar_c, front_c, central_c, back_c, nasal_c, stop_c, syllabic_c, additional_c

c = Converter(system="IPA", punctuation='none')
c_north = Converter(system="IPA", dialect="north", punctuation='none')

def test_ipa_initials():
    bilabial = ['pi⁴⁴/pi⁵⁵','pʰə⁴⁴/pʰo⁵⁵','mɔ̃²⁵/mɔ̃²⁴','ba²⁵/ba²⁴']
    checker(list(zip(bilabial_c, bilabial)), c, c_north)
    alveolar = ['te²²/tue³³','tʰə¹¹/tʰo²¹','tsa⁵³/tsa⁵¹','tsʰu¹¹/tsʰu²¹','su⁴⁴/su⁵⁵','nãi²²/nãi³³','dzu²⁵/lu²⁴','liu⁵³/liu⁵¹']
    checker(list(zip(alveolar_c, alveolar)), c, c_north)
    alveolo_palatal = ['tɕia⁴⁴/tɕia⁵⁵','tɕʰiu⁵³/tɕʰiu⁵¹','ɕia⁵³/ɕia⁵¹','dʑi²⁵/li²⁴']
    checker(list(zip(alveolo_palatal_c, alveolo_palatal)), c, c_north)
    velar = ['kiu²⁵/kiu²⁴','kʰi¹¹/kʰi²¹','ŋã⁵³/ŋã⁵¹','gi⁵³/gu⁵¹','hi⁵³/hi⁵¹']
    checker(list(zip(velar_c, velar)), c, c_north)

def test_ipa_vowels_and_rhymes():
    front = ['i⁴⁴/i⁵⁵','e²²/e³³','ĩ²⁵/ĩ²⁴','ẽ²⁵/ẽ²⁴']
    checker(list(zip(front_c, front)), c, c_north)
    central = ['ə⁴⁴/o⁵⁵','a⁴⁴/a⁵⁵','ã²²/ã³³']
    checker(list(zip(central_c, central)), c, c_north)
    back = ['u⁵³/u⁵¹','ɔ⁴⁴/ɔ⁵⁵','tiũ⁴⁴/tiũ⁵⁵','ɔ̃⁴⁴/ɔ̃⁵⁵']
    checker(list(zip(back_c, back)), c, c_north)

def test_ipa_finals():
    nasal = ['im⁴⁴/im⁵⁵','in²⁵/in²⁴','aŋ²⁵/aŋ²⁴']
    checker(list(zip(nasal_c, nasal)), c, c_north)
    stop = ['iap̚⁵/iap̚⁴','at̚²¹/at̚³²','ɔk̚²¹/ɔk̚³²','aʔ⁵/aʔ⁴']
    checker(list(zip(stop_c, stop)), c, c_north)
    syllabic = ['m̩⁵³/m̩⁵¹','ŋ̍²⁵/ŋ̍²⁴']
    checker(list(zip(syllabic_c, syllabic)), c, c_north)

def test_ipa_syllables_additional():
    additional = ["tsã²²/tsã³³","it̚²¹ kʰai¹¹/it̚³² kʰai²¹","sam⁴⁴ tsan¹¹/sam⁵⁵ tsan²¹","put̚²¹ sut̚²¹/put̚³² sut̚³²","tʰiu⁵³/tʰiu⁵¹","tɔm²⁵/tɔm²⁴","hɔ̃","kʰit̚²¹ tɕiaʔ⁵/kʰit̚³² tɕiaʔ⁴","luan²² tɕiɪŋ⁴⁴/luan³³ tɕiɪŋ⁵⁵","ka⁴⁴ lauʔ⁵/ka⁵⁵ lauʔ⁴","dʑin²⁵ kan⁴⁴/lin²⁴ kan⁵⁵","giɔŋ⁵³ kak̚²¹/giɔŋ⁵¹ kak̚³²","hiu⁴⁴ kʰiɪk̚²¹/hiu⁵⁵ kʰiɪk̚³²","bu⁵³ dʑiɔk̚⁵/bu⁵¹ liɔk̚⁴","tʰiɪŋ²⁵ tiɛn²²/tʰiɪŋ²⁴ tiɛn³³","ãi²²/iaŋ³³","tʰuan²⁵ tɕiap̚²¹/tʰuan²⁴ tɕiap̚³²","hiau⁴⁴ hiɪŋ²²/hiau⁵⁵ hiɪŋ³³","giam⁵³ ŋẽ²²/giam⁵¹ ŋĩ³³","hiã⁴⁴ kə⁴⁴/hiã⁵⁵ ko⁵⁵","tɕʰiɔŋ⁴⁴ tsɔk̚²¹/tɕʰiɔŋ⁵⁵ tsɔk̚³²","biɛn⁵³ hui¹¹/biɛn⁵¹ hui²¹","dʑip̚⁵ kʰau⁵³/lip̚⁴ kʰau⁵¹","pat̚²¹ ɕiɛn⁴⁴/pat̚³² ɕiɛn⁵⁵","peʔ²¹ gueʔ⁵ tseʔ²¹/pueʔ³² geʔ⁴ tsueʔ³²","pʰã¹¹ pʰuʔ⁵/pʰã²¹ pʰuʔ⁴","piɪŋ⁴⁴ pʰauʔ⁵/piɪŋ⁵⁵ pʰauʔ⁴","tãi⁵³/tãi⁵¹","pʰuã¹¹ tuan¹¹/pʰuã²¹ tuan²¹","piɛt̚⁵ tsɔŋ⁴⁴/piɛt̚⁴ tsɔŋ⁵⁵","kueʔ²¹/kuiʔ³²","tʰak̚²¹ tʰiɪk̚²¹/tʰak̚³² tʰiɪk̚³²","kat̚²¹ le⁵³/kat̚³² le⁵¹","ueʔ⁵/uiʔ⁴","ka⁴⁴ kʰuai¹¹/ka⁵⁵ kʰuai²¹","luat̚⁵/luat̚⁴","kiap̚²¹ kuan⁴⁴/kiap̚³² kuan⁵⁵","tsʰɔŋ⁴⁴ tɕʰiɔk̚²¹/tsʰɔŋ⁵⁵ tɕʰiɔk̚³²","pʰit̚²¹ tiɪk̚⁵/pʰit̚³² tiɪk̚⁴","puan¹¹ sui²²/puan²¹ sui³³","hiap̚⁵ hə²⁵/hiap̚⁴ ho²⁴","kʰaʔ²¹ pʰĩ¹¹/kʰaʔ³² pʰĩ²¹","bau⁵³ miã²⁵/bau⁵¹ miã²⁴","mãuʔ²¹ ləʔ⁵ kʰi¹¹/mãuʔ³² loʔ⁴ kʰi²¹","gui²⁵ hiam⁵³/gui²⁴ hiam⁵¹","nŋ̍²² pau⁴⁴/nŋ̍³³ pau⁵⁵","tsʰam⁴⁴ tɕiau¹¹/tsʰam⁵⁵ tɕiau²¹","hap̚⁵ huan⁴⁴/hap̚⁴ huan⁵⁵","ham²⁵ tʰiɔk̚²¹/ham²⁴ tʰiɔk̚³²","kʰŋ̍ʔ²¹/kʰŋ̍ʔ³²","kʰip̚²¹ kuã²²/kʰip̚³² kuã³³","bun⁵³ tɕʰiə¹¹/bun⁵¹ tɕʰio²¹","eʔ²¹ sŋ̍⁴⁴/eʔ³² sŋ̍⁵⁵","kʰuʔ²¹/kʰuʔ³²","pʰin⁵³ ɕiɔŋ²⁵/pʰin⁵¹ ɕiɔŋ²⁴","haʔ²¹ tɕʰiũ¹¹/haʔ³² tɕʰiũ²¹","ha⁴⁴ kʰui¹¹/ha⁵⁵ kʰui²¹","hãi⁴⁴ tsʰan⁴⁴/hãi⁵⁵ tsʰan⁵⁵","haiʔ²¹/haiʔ³²","kʰẽʔ⁵/kʰẽʔ⁴","nãuʔ²¹/nãuʔ³²","iaũ⁴⁴/iaũ⁵⁵","ɔ","huaʔ²¹ liɪŋ²²/huaʔ³² liɪŋ³³","sãʔ²¹/sãʔ³²","pʰŋ̍ʔ²¹/pʰŋ̍ʔ³²","tsak̚⁵/tsak̚⁴","tsʰauʔ⁵ tsʰauʔ⁵ liam²²/tsʰauʔ⁴ tsʰauʔ⁴ liam³³","hau⁴⁴ ɕiau²⁵/hau⁵⁵ ɕiau²⁴","uʔ²¹/uʔ³²","aiʔ²¹/aiʔ³²","hm̩ʔ⁵/hm̩ʔ⁴","heʔ²¹ kiã⁴⁴/heʔ³² kiã⁵⁵","tɕʰiak̚⁵/tɕʰiak̚⁴","dʑiaŋ⁵³/liɔŋ⁵¹","uaŋ⁴⁴/uaŋ⁵⁵","tun⁵³ tiaʔ⁵/tun⁵¹ tiaʔ⁴","kʰun¹¹ kiɔk̚⁵/kʰun²¹ kiɔk̚⁴","ĩ²⁵ sɔm⁴⁴/ĩ²⁴ sɔm⁵⁵","tsai²²/tsai³³","tʰun²² tʰɔ²⁵/tʰun³³ tʰɔ²⁴","kʰẽ⁴⁴ kɔk̚²¹/kʰĩ⁵⁵ kɔk̚³²","iɪŋ⁴⁴ ia⁴⁴/iɪŋ⁵⁵ ia⁵⁵","laʔ²¹ sap̚²¹/laʔ³² sap̚³²","ki⁴⁴ kim⁴⁴/ki⁵⁵ kim⁵⁵","giau²⁵ ku⁵³/giau²⁴ ku⁵¹","tʰap̚²¹ tʰe¹¹/tʰap̚³² tʰue²¹","piaʔ²¹ ue²²/piaʔ³² ue³³","ap̚²¹ bɔ²⁵/ap̚³² bɔ²⁴","gue²² ɕiɪŋ⁴⁴/gue³³ ɕiɪŋ⁵⁵","Tua²² suã⁴⁴/Tua³³ suã⁵⁵","tʰĩ⁴⁴ kŋ̍⁴⁴/tʰĩ⁵⁵ kŋ̍⁵⁵","tʰiɛn⁴⁴ hiə²²/tʰiɛn⁵⁵ hio³³","Tʰai¹¹ lɔ⁵³ kəʔ²¹/Tʰai²¹ lɔ⁵¹ koʔ³²","iaŋ⁴⁴ kip̚⁵/iaŋ⁵⁵ kip̚⁴","kʰia⁴⁴ ɕiaŋ⁴⁴/kʰia⁵⁵ ɕiaŋ⁵⁵","pʰun⁴⁴ sɔŋ⁴⁴/pʰun⁵⁵ sɔŋ⁵⁵","hɔ̃¹¹ kʰeʔ²¹/hɔ̃²¹ kʰeʔ³²","miãu²²/miãu³³","tsŋ̍⁴⁴ tʰã²²/tsŋ̍⁵⁵ tʰã³³","tɕʰiap̚²¹/tɕʰiap̚³²","sẽ¹¹/ɕĩ²¹","mã⁴⁴ mã⁴⁴/mã⁵⁵ mã⁵⁵","pu²²/pu³³","hak̚⁵ hŋ̍²⁵/hak̚⁴ hŋ̍²⁴","əʔ⁵ pʰãi⁵³/oʔ⁴ pʰai⁵¹","giɛt̚⁵/giɛt̚⁴","tʰeʔ⁵/tʰeʔ⁴","an⁴⁴ bin²⁵/an⁵⁵ bin²⁴","kia¹¹ lai²⁵/kia²¹ lai²⁴","bat̚⁵ tsat̚⁵/bat̚⁴ tsat̚⁴","tsuan⁴⁴ uan²⁵/tsuan⁵⁵ uan²⁴","dʑiə²² kɔ⁵³/lio³³ kɔ⁵¹","pʰui¹¹/pʰui²¹","kai¹¹ ɕi²⁵/kai²¹ ɕi²⁴","kʰut̚²¹ kiə²⁵/kʰut̚³² kio²⁴","pin²⁵ tɕia⁴⁴ nã⁵³/pin²⁴ tɕia⁵⁵ nã⁵¹","kiaʔ⁵/kiaʔ⁴","gam²⁵ iam²⁵/gam²⁴ iam²⁴","gak̚⁵ hu²²/gak̚⁴ hu³³","nĩ²⁵ piə⁵³/nĩ²⁴ pio⁵¹","tiam¹¹ tsɔ⁴⁴/tiam²¹ tsɔ⁵⁵","am⁴⁴ biə²²/am⁵⁵ bio³³","dʑiap̚⁵/liap̚⁴","piu⁴⁴/piu⁵⁵","hit̚²¹ iũ²²/hit̚³² iũ³³","kʰiə¹¹/kʰio²¹","dʑim⁵³ ɕim⁴⁴/lim⁵¹ ɕim⁵⁵","kʰuĩ¹¹ uaʔ⁵/kʰuĩ²¹ uaʔ⁴","hut̚²¹ dʑiɛn²⁵/hut̚³² liɛn²⁴","pʰẽ²²/pʰẽ³³","kʰiap̚²¹ tã⁵³/kʰiap̚³² tã⁵¹","kʰiɔŋ⁵³ ui¹¹/kʰiɔŋ⁵¹ ui²¹","ɕiəʔ²¹ liəʔ⁵/ɕioʔ³² lioʔ⁴","gɔk̚⁵/gɔk̚⁴","gaŋ²²/gaŋ³³","tsʰeʔ²¹ ɕim⁴⁴/tsʰueʔ³² ɕim⁵⁵","tan²²/tan³³","nɔ̃²²/nɔ̃³³","huai²⁵ liam²²/huai²⁴ liam³³","gɔŋ²²/gɔŋ³³","pe⁴⁴ pŋ̍²²/pe⁵⁵ pŋ̍³³","ŋiũ⁵³ kʰa⁴⁴ tsʰŋ̍⁴⁴/ŋiũ⁵¹ kʰa⁵⁵ tsʰŋ̍⁵⁵","dʑiau¹¹ tɕiũ²²/liau²¹ tɕiũ³³","pʰi⁴⁴ tiã²⁵/pʰi⁵⁵ tiã²⁴","buaʔ²¹ hun⁵³/buaʔ³² hun⁵¹","kʰiəʔ²¹ ɕip̚⁵/kʰioʔ³² ɕip̚⁴","tʰiaʔ²¹ tuã²⁵/tʰiaʔ³² tuã²⁴","pʰau⁴⁴ tsʰut̚²¹/pʰau⁵⁵ tsʰut̚³²","pʰa⁴⁴ sa⁴⁴/pʰa⁵⁵ sa⁵⁵","pʰaʔ²¹ tsʰap̚²¹/pʰaʔ³² tsʰap̚³²","tʰua⁴⁴ tit̚⁵/tʰua⁵⁵ tit̚⁴","tɕiə⁴⁴ ua⁵³/tɕio⁵⁵ ua⁵¹","kuaʔ²¹ lau²⁵/kuaʔ³² lau²⁴","tsãi⁵³/tsãi⁵¹","tʰa¹¹/tʰa²¹","hĩ¹¹ sak̚²¹/hĩ²¹ sak̚³²","ai⁴⁴ gə²²/ai⁵⁵ go³³","hiɛn⁴⁴ tsʰeʔ²¹/hiɛn⁵⁵ tsʰeʔ³²","sau¹¹ tɔŋ²²/sau²¹ tɔŋ³³","tuaʔ²¹/tuaʔ³²","tɕiã²²/tɕiã³³","ɔm⁴⁴ bak̚⁵ ke⁴⁴/ɔm⁵⁵ bak̚⁴ kue⁵⁵","tsʰaʔ²¹ tsʰun⁴⁴/tsʰaʔ³² tsʰun⁵⁵","tuʔ⁵/tuʔ⁴","tiuʔ²¹/tiuʔ³²","taʔ²¹ hiãʔ²¹/taʔ³² hiãʔ³²","Taʔ²¹ li⁵³ bu²²/Taʔ³² li⁵¹ bu³³","kʰaũʔ⁵/kʰaũʔ⁴","pʰiɛt̚²¹ tɕʰiɪŋ⁴⁴/pʰiɛt̚³² tɕʰiɪŋ⁵⁵","ŋiãu⁵³/ŋiãu⁵¹","tʰiɛt̚²¹ tɕit̚²¹/tʰiɛt̚³² tɕit̚³²","tiak̚⁵/tiak̚⁴","tam⁴⁴ tŋ̍⁴⁴/tam⁵⁵ tŋ̍⁵⁵","pʰiak̚⁵/pʰiak̚⁴","pʰan⁴⁴ tiɪŋ⁴⁴/pʰan⁵⁵ tiɪŋ⁵⁵","nuã²⁵ tsaʔ⁵/nuã²⁴ tsaʔ⁴","kʰãi⁵³/kʰãi⁵¹","tʰin²⁵ tɕiu⁵³/tʰin²⁴ tɕiu⁵¹","hɔŋ⁴⁴ hiɪŋ⁴⁴ bi²² ŋãi²²/hɔŋ⁵⁵ hiɪŋ⁵⁵ bi³³ ŋãi³³","tsəʔ⁵/tsoʔ⁴","buan⁵³ hue²²/buan⁵¹ he³³","tsẽ²⁵/tɕĩ²⁴","nẽ²⁵/nẽ²⁴","kʰiɔk̚²¹ suã¹¹/kʰiɔk̚³² suã²¹","lɔŋ⁵³ tʰɔk̚⁵/lɔŋ⁵¹ tʰɔk̚⁴","bɔk̚⁵ giap̚⁵/bɔk̚⁴ giap̚⁴","buat̚⁵ lɔ²²/buat̚⁴ lɔ³³","tʰu⁵³/tʰu⁵¹","kuai⁵³/kuai⁵¹","dʑiam⁵³/liam⁵¹","kau¹¹ uat̚⁵/kau²¹ uat̚⁴","hiɪk̚⁵ kʰə⁵³/hiɪk̚⁴ kʰo⁵¹","təʔ²¹ tʰuaʔ²¹/toʔ³² tʰuaʔ³²","dʑiu²⁵/liu²⁴","piau⁴⁴ pun⁵³/piau⁵⁵ pun⁵¹","pʰəʔ²¹ ɕit̚⁵/pʰoʔ³² ɕit̚⁴","huãi²⁵ keʔ⁵/huĩ²⁴ keʔ⁴","suãi²²/suãi³³","suʔ²¹/suʔ³²","hiəʔ²¹ iã⁵³/hioʔ³² iã⁵¹","kua⁴⁴ pʰɔ⁵³/kua⁵⁵ pʰɔ⁵¹","huã⁴⁴ tɔ²²/huã⁵⁵ tɔ³³","uai⁴⁴ tsʰuaʔ⁵/uai⁵⁵ tsʰuaʔ⁴","muĩ⁵³ pai⁵³/muĩ⁵¹ pai⁵¹","ak̚²¹ hɔ²²/ak̚³² hɔ³³","tim²⁵ tiɔk̚⁵/tim²⁴ tiɔk̚⁴","but̚⁵ iəʔ⁵/but̚⁴ ioʔ⁴","tauʔ⁵/tauʔ⁴","tap̚⁵ tiʔ²¹/tap̚⁴ tiʔ³²","tɕʰiaŋ²⁵ tsui⁵³/tɕʰiaŋ²⁴ tsui⁵¹","pʰueʔ⁵/pʰeʔ⁴","hai⁵³ he²²/hai⁵¹ he³³","liaŋ²⁵ kʰiɔŋ⁴⁴/liaŋ²⁴ kʰiɔŋ⁵⁵","tʰiam⁴⁴ ɕiɛt̚²¹/tʰiam⁵⁵ ɕiɛt̚³²","biau⁵³ bɔŋ²⁵/biau⁵¹ bɔŋ²⁴","tʰuã¹¹ tsaŋ²⁵/tʰuã²¹ tsaŋ²⁴","biɛt̚⁵ bə²⁵/biɛt̚⁴ bo²⁴","pʰiau⁴⁴ pʰu²⁵/pʰiau⁵⁵ pʰu²⁴","lɔk̚²¹ sai⁵³/lɔk̚³² sai⁵¹","au⁴⁴ pui²⁵/au⁵⁵ pui²⁴","tɕiaŋ⁴⁴/tɕiaŋ⁵⁵","pʰuaʔ²¹ ɕĩ¹¹/pʰuaʔ³² ɕĩ²¹","pʰuat̚²¹ tɕian²²/pʰuat̚³² tɕian³³","dzun²² piã⁵³/lun³³ piã⁵¹","haũʔ⁵/haũʔ⁴","kiɪk̚²¹ lat̚⁵/kiɪk̚³² lat̚⁴","tsuã²²/tsuã³³","piak̚²¹/piak̚³²","saʔ⁵/saʔ⁴","muẽ²⁵/muẽ²⁴","hãʔ²¹/hãʔ³²","him²⁵/him²⁴","dʑiɛt̚⁵ liɛt̚⁵/liɛt̚⁴ liɛt̚⁴","nãʔ²¹/nãʔ³²","tia⁴⁴/tia⁵⁵","tʰẽ¹¹/tʰẽ²¹","giu²⁵ tɕʰiɪk̚²¹/giu²⁴ tɕʰiɪk̚³²","mĩʔ⁵/mŋ̍ʔ⁴","mĩʔ²¹ tai²²/mĩʔ³² tai³³","kʰiɛn⁴⁴ kiɔŋ²⁵/kʰiɛn⁵⁵ kiɔŋ²⁴","kʰan⁴⁴ kʰap̚⁵/kʰan⁵⁵ kʰap̚⁴","biɪŋ⁵³ iɔŋ⁵³/biɪŋ⁵¹ iɔŋ⁵¹","giɪk̚⁵ kʰuan²⁵/giɪk̚⁴ kʰuan²⁴","giɔk̚⁵ lan²⁵/giɔk̚⁴ lan²⁴","guan⁵³ kʰu²²/guan⁵¹ kʰu³³","kam⁴⁴ kʰɔ⁵³/kam⁵⁵ kʰɔ⁵¹","lut̚²¹ mŋ̍²⁵/lut̚³² mŋ̍²⁴","han⁴⁴ tɕi²⁵/han⁵⁵ tsu²⁴","tʰiap̚⁵ tɕiam⁴⁴/tʰiap̚⁴ tɕiam⁵⁵","sɔ⁴⁴ san¹¹/sɔ⁵⁵ san²¹","giɛn¹¹ kaʔ²¹/giɛn²¹ kaʔ³²","paʔ²¹ puã⁴⁴/paʔ³² puã⁵⁵","iɪk̚²¹ tʰiɔŋ²⁵/iɪk̚³² tʰiɔŋ²⁴","iaʔ²¹ kəʔ²¹/iaʔ³² koʔ³²","kã⁴⁴ lə²⁵/kã⁵⁵ lo²⁴","ɕiə⁴⁴ ɕiam⁵³/ɕio⁵⁵ ɕiam⁵¹","bai²⁵ hiaʔ⁵/bai²⁴ hiaʔ⁴","kʰuã¹¹/kʰuã²¹","hin²⁵ sua⁴⁴/hin²⁴ sua⁵⁵","tsʰuʔ²¹/tsʰuʔ³²","gan⁵³ hɔk̚²¹/gan⁵¹ hɔk̚³²","kãi²⁵/kãi²⁴","tɔk̚²¹ tsʰat̚²¹/tɔk̚³² tsʰat̚³²","kʰeʔ²¹/kʰueʔ³²","kiʔ²¹/kiʔ³²","giɪŋ⁵³ puaʔ²¹/giɪŋ⁵¹ puaʔ³²","pʰua¹¹ kʰiʔ²¹/pʰua²¹ kʰiʔ³²","teʔ²¹/teʔ³²","uã⁵³ tʰau²⁵ ti²² bue⁵³/uã⁵¹ tʰau²⁴ tu³³ be⁵¹","pʰiɪk̚²¹ tʰam²⁵/pʰiɪk̚³² tʰam²⁴","kʰak̚²¹ pə⁵³/kʰak̚³² po⁵¹","bua²⁵ kʰã⁴⁴/bua²⁴ kʰã⁵⁵","ta⁴⁴ tɕiəʔ⁵/ta⁵⁵ tɕioʔ⁴","tsʰɔ⁵³/tsʰɔ⁵¹","gai²² tiəʔ⁵/gai³³ tioʔ⁴","pʰiə¹¹ ɕiũ⁴⁴/pʰio²¹ ɕiũ⁵⁵","tʰut̚²¹/tʰut̚³²","kʰaŋ⁴⁴ kʰaŋ⁴⁴/kʰaŋ⁵⁵ kʰaŋ⁵⁵","tut̚⁵/tut̚⁴","leʔ⁵/lueʔ⁴","pit̚²¹ suan¹¹/pit̚³² suan²¹","tsʰɔk̚²¹/tsʰɔk̚³²","pua¹¹/pua²¹","tɕʰiam⁴⁴ ɔŋ²⁵/tɕʰiam⁵⁵ ɔŋ²⁴","liap̚⁵/liap̚⁴","kʰŋ̍⁴⁴ tsʰŋ̍⁴⁴/kʰŋ̍⁵⁵ tsʰŋ̍⁵⁵","tʰiə¹¹/tʰio²¹","tiu²²/tiu³³","lap̚⁵ tsʰai⁵³/lap̚⁴ tsʰai⁵¹","səʔ²¹ tʰui⁴⁴/soʔ³² tʰui⁵⁵","lui⁵³ tɕiɪk̚²¹/lui⁵¹ tɕiɪk̚³²","kʰɔŋ⁵³/kʰɔŋ⁵¹","kiɛt̚²¹ pa⁴⁴/kiɛt̚³² pa⁵⁵","tsuat̚⁵ tui¹¹/tsuat̚⁴ tui²¹","dʑiɔŋ²⁵ pɔ¹¹/liɔŋ²⁴ pɔ²¹","kẽ⁴⁴ kiɛn⁵³/kĩ⁵⁵ kiɛn⁵¹","liɪk̚⁵ ɕiɪk̚²¹/liɪk̚⁴ ɕiɪk̚³²","tɕʰip̚²¹ pɔ⁵³/tɕʰip̚³² pɔ⁵¹","tʰɔŋ²²/tʰɔŋ³³","piɛn⁴⁴ tsʰuan¹¹/piɛn⁵⁵ tsʰuan²¹","kʰuat̚²¹ nĩu²⁵/kʰuat̚³² nĩu²⁴","bi⁵³ bi²²/bi⁵¹ bi³³","hip̚²¹ dzuaʔ⁵/hip̚³² luaʔ⁴","pʰiɪŋ¹¹ tɕʰiã⁵³/pʰiɪŋ²¹ tɕʰiã⁵¹","tʰiã⁴⁴ tsʰə¹¹/tʰiã⁵⁵ tsʰo²¹","baʔ²¹ bak̚⁵/baʔ³² bak̚⁴","mẽʔ⁵ pʰɔk̚²¹/mẽʔ⁴ pʰɔk̚³²","tʰuat̚²¹ tɕiat̚²¹/tʰuat̚³² tɕiat̚³²","kʰiũ⁴⁴ tiau²²/kʰiũ⁵⁵ tiau³³","iə⁴⁴ kut̚²¹/io⁵⁵ kut̚³²","kiəʔ²¹ tɕĩ²⁵/kioʔ³² tɕĩ²⁴","tsun²⁵ un²²/tsun²⁴ un³³","ɕiɪk̚²¹ ga²⁵/ɕiɪk̚³² ga²⁴","mãu²⁵ tsʰau⁵³/mãu²⁴ tsʰau⁵¹","tsʰau⁵³ leʔ⁵ a⁵³/tsʰau⁵¹ lueʔ⁴ a⁵¹","ŋẽʔ²¹/ŋẽʔ³²","lak̚²¹ ləʔ⁵/lak̚³² loʔ⁴","tɕʰiəʔ⁵/tɕʰioʔ⁴","tsʰaŋ⁴⁴ ŋãu²²/tsʰaŋ⁵⁵ ŋãu³³","kueʔ²¹ niãu⁴⁴/kueʔ³² niãu⁵⁵","pɔk̚⁵ tʰai²²/pɔk̚⁴ tʰai³³","pəʔ⁵ mɔ̃ʔ⁵/poʔ⁴ mɔ̃ʔ⁴","kiũ⁴⁴/kiũ⁵⁵","hiauʔ²¹/hiauʔ³²","pʰuan⁴⁴ pin²⁵/pʰuan⁵⁵ pin²⁴","kʰiɪŋ²²/kʰiɪŋ³³","tsuaʔ⁵/tsuaʔ⁴","kap̚²¹ la²⁵/kap̚³² la²⁴","ɕiɔk̚⁵ tɕʰit̚²¹/ɕiɔk̚⁴ tɕʰit̚³²","gia²⁵ kaŋ⁴⁴/gia²⁴ kaŋ⁵⁵","bit̚⁵ guat̚⁵/bit̚⁴ guat̚⁴","ɕiʔ⁵ tɕʰin¹¹/ɕiʔ⁴ tɕʰin²¹","bui⁴⁴/bui⁵⁵","sat̚²¹/sat̚³²","giə²⁵ pue⁴⁴/gio²⁴ pue⁵⁵","ŋiãuʔ⁵ ŋiãuʔ⁵ taŋ²²/ŋiãuʔ⁴ ŋiãuʔ⁴ taŋ³³","tɕim²⁵/tɕim²⁴","tʰan⁴⁴ pʰiã²⁵/tʰan⁵⁵ pʰiã²⁴","baŋ⁵³ tau¹¹/baŋ⁵¹ tau²¹","tɕʰiʔ⁵/tɕʰiʔ⁴","ban²⁵ pʰue²⁵ pẽ²²/ban²⁴ pʰe²⁴ pĩ³³","hueʔ²¹ iu²⁵/huiʔ³² iu²⁴","hiɛt̚²¹ iɛn²⁵/hiɛt̚³² iɛn²⁴","liʔ⁵ pʰaŋ²²/liʔ⁴ pʰaŋ³³","liaʔ²¹ kʰiaʔ²¹/liaʔ³² kʰiaʔ³²","tʰŋ̍¹¹/tʰŋ̍²¹","tʰi⁵³ tuat̚⁵/tʰi⁵¹ tuat̚⁴","kʰim⁴⁴ tɕiɔŋ⁴⁴/kʰim⁵⁵ tɕiɔŋ⁵⁵","bueʔ⁵ sɔk̚²¹/bueʔ⁴ sɔk̚³²","kui⁴⁴ mẽ²⁵/kui⁵⁵ mĩ²⁴","biʔ²¹ tsʰui¹¹/biʔ³² tsʰui²¹","tak̚²¹ tĩ²⁵/tak̚³² tĩ²⁴","kuat̚²¹ suat̚²¹/kuat̚³² suat̚³²","kʰiɛt̚²¹ tɕiʔ⁵/kʰiɛt̚³² tɕiʔ⁴","kʰua⁴⁴ tiɔŋ⁴⁴/kʰua⁵⁵ tiɔŋ⁵⁵","tiap̚⁵/tiap̚⁴","giəʔ⁵ ɕiaʔ²¹/gioʔ⁴ ɕiaʔ³²","pɔŋ¹¹ tua²²/pɔŋ²¹ tua³³","kʰiam⁴⁴ sun¹¹/kʰiam⁵⁵ sun²¹","biu²² gɔ²²/biu³³ gɔ³³","hɔʔ²¹/hɔʔ³²","pʰɔŋ⁴⁴ pʰai¹¹/pʰɔŋ⁵⁵ pʰai²¹","mãi⁵³ tɕiɔk̚²¹/mãi⁵¹ tɕiɔk̚³²","lua²²/lua³³","tɕʰiaʔ²¹ tɕin⁵³/tɕʰiaʔ³² tɕin⁵¹","tɕʰiau⁴⁴ tɕʰi²²/tɕʰiau⁵⁵ tɕʰi³³","sə²⁵/so²⁴","puat̚⁵ ɕiap̚⁵/puat̚⁴ ɕiap̚⁴","dʑiaʔ²¹/liaʔ³²","kʰa⁴⁴ kʰiau⁴⁴/kʰa⁵⁵ kʰiau⁵⁵","tsuãi²²/tsuãi³³","tʰiau¹¹ tʰat̚²¹/tʰiau²¹ tʰat̚³²","pʰiʔ²¹ tə⁵³/pʰiʔ³² to⁵¹","nẽʔ²¹/nĩʔ³²","kʰin⁴⁴ ɕiã⁴⁴ se¹¹ sueʔ²¹/kʰin⁵⁵ ɕiã⁵⁵ sue²¹ seʔ³²","hat̚²¹ kiɪŋ⁵³/hat̚³² kiɪŋ⁵¹","pʰiɪk̚²¹ tsau⁵³/pʰiɪk̚³² tsau⁵¹","ŋiã²⁵ ɕin²⁵/ŋiã²⁴ ɕin²⁴","hã²²/hã³³","piɪk̚²¹ tɕʰiat̚²¹/piɪk̚³² tɕʰiat̚³²","tiɛt̚⁵/tiɛt̚⁴","piaŋ¹¹/piaŋ²¹","saŋ¹¹ tat̚⁵/saŋ²¹ tat̚⁴","tsua²²/tsua³³","dʑia⁴⁴ kʰam¹¹/lia⁵⁵ kʰam²¹","iau⁴⁴ iɔk̚²¹/iau⁵⁵ iɔk̚³²","ip̚²¹/ip̚³²","nã⁵³ tʰaŋ⁴⁴/nã⁵¹ tʰaŋ⁵⁵","hiɔk̚²¹/hiɔk̚³²","tẽ²²/tẽ³³","kʰɔk̚²¹ laŋ²⁵/kʰɔk̚³² laŋ²⁴","taŋ²² tsʰẽ⁴⁴/taŋ³³ tɕʰĩ⁵⁵","tiə¹¹ tsə²⁵/tio²¹ tso²⁴","gin²⁵ huat̚²¹/gun²⁴ huat̚³²","dzue²² kiam⁵³/lue³³ kiam⁵¹","tsʰã²²/tsʰã³³","gim⁵³ ɕiu¹¹/gim⁵¹ ɕiu²¹","tin¹¹ suaʔ²¹/tin²¹ suaʔ³²","tsam²²/tsam³³","tʰiʔ²¹ tʰaʔ²¹/tʰiʔ³² tʰaʔ³²","ɕiak̚²¹/ɕiak̚³²","tɕʰim²⁵/tɕʰim²⁴","tsʰak̚⁵/tsʰak̚⁴","tsʰuã¹¹/tsʰuã²¹","iɛt̚⁵ lam⁵³/iɛt̚⁴ lam⁵¹","kʰuaʔ²¹ pak̚²¹/kʰuaʔ³² pak̚³²","tsʰuaŋ¹¹/tsʰuaŋ²¹","kuãi⁴⁴ tɕʰia⁴⁴/kuĩ⁵⁵ tɕʰia⁵⁵","tɕʰian⁵³/tɕʰian⁵¹","a⁴⁴ sa⁴⁴ puʔ²¹ luʔ²¹/a⁵⁵ sa⁵⁵ puʔ³² luʔ³²","ham²²/ham³³","tsap̚⁵ tsʰa²⁵/tsap̚⁴ tsʰa²⁴","ke⁴⁴ tse²⁵ kin⁴⁴/kue⁵⁵ tsue²⁴ kun⁵⁵","hia⁴⁴ kɔŋ⁵³/hia⁵⁵ kɔŋ⁵¹","haŋ²²/haŋ³³","niã⁵³ pan⁴⁴/niã⁵¹ pan⁵⁵","giaʔ⁵ gua²²/giaʔ⁴ gua³³","hɔŋ⁴⁴ tsʰue⁴⁴ dʑit̚⁵ pʰak̚⁵/hɔŋ⁵⁵ tsʰe⁵⁵ lit̚⁴ pʰak̚⁴","hiũ⁴⁴/hiũ⁵⁵","hiaŋ⁴⁴ hm̩²⁵/hiaŋ⁵⁵ hm̩²⁴","hiɔŋ⁴⁴ hua⁴⁴/hiɔŋ⁵⁵ hua⁵⁵","pʰiɛn¹¹/pʰiɛn²¹","kiau⁴⁴ ŋɔ̃²²/kiau⁵⁵ ŋɔ̃³³","nãu²² paŋ²⁵/nãu³³ paŋ²⁴","ut̚²¹ tsut̚²¹/ut̚³² tsut̚³²","tʰəʔ²¹/tʰoʔ³²","piʔ²¹/piʔ³²","tʰim⁴⁴/tʰim⁵⁵","həʔ⁵/hoʔ⁴","beʔ⁵ ge²⁵/beʔ⁴ ge²⁴","muã²⁵ sã⁴⁴/muã²⁴ sã⁵⁵","biɪk̚⁵ kʰe¹¹/biɪk̚⁴ kʰue²¹","tʰuʔ²¹/tʰuʔ³²","giaŋ¹¹/giaŋ²¹","pʰiaŋ²²/pʰiaŋ³³","gau²⁵/gau²⁴","tɕip̚⁵/tɕip̚⁴","kʰat̚²¹/kʰat̚³²","tsʰua²²/tsʰua³³","tsʰəʔ²¹/tsʰoʔ³²","pʰut̚⁵/pʰut̚⁴","uãi⁵³/uãi⁵¹","kʰiu²²/kʰiu³³","kauʔ²¹/kauʔ³²"]
    checker(list(zip(additional_c, additional)), c, c_north)